@@ -59,7 +59,9 @@ class Label(displayio.Group):
      (E.g. (0,0) is top left, (1.0, 0.5): is middle right.)
     :param (int,int) anchored_position: Position relative to the anchor_point. Tuple
      containing x,y pixel coordinates.
-    :param int scale: Integer value of the pixel scaling"""
+    :param int scale: Integer value of the pixel scaling
+    :param bool base_alignment: when True allows to align text label to the baseline.
+     This is helpful when two or more labels need to be aligned to the same baseline"""
 
     # pylint: disable=too-many-instance-attributes, too-many-locals
     # This has a lot of getters/setters, maybe it needs cleanup.
@@ -83,6 +85,7 @@ class Label(displayio.Group):
         anchor_point=None,
         anchored_position=None,
         scale=1,
+        base_alignment=False,
         **kwargs
     ):
         if not max_glyphs and not text:
@@ -129,8 +132,7 @@ class Label(displayio.Group):
         self._padding_bottom = padding_bottom
         self._padding_left = padding_left
         self._padding_right = padding_right
-
-        self._scale = scale
+        self.base_alignment = base_alignment
 
         if text is not None:
             self._update_text(str(text))
@@ -161,7 +163,10 @@ class Label(displayio.Group):
                 + self._padding_top
                 + self._padding_bottom
             )
-            y_box_offset = -ascent + y_offset - self._padding_top
+            if self.base_alignment:
+                y_box_offset = -ascent - self._padding_top
+            else:
+                y_box_offset = -ascent + y_offset - self._padding_top
 
         box_width = max(0, box_width)  # remove any negative values
         box_height = max(0, box_height)  # remove any negative values
@@ -265,8 +270,10 @@ class Label(displayio.Group):
         else:
             i = 0
         tilegrid_count = i
-
-        y_offset = self._get_ascent() // 2
+        if self.base_alignment:
+            y_offset = 0
+        else:
+            y_offset = self._get_ascent() // 2
 
         right = top = bottom = 0
         left = None
@@ -389,12 +396,11 @@ class Label(displayio.Group):
     @property
     def scale(self):
         """Set the scaling of the label, in integer values"""
-        return self._scale
+        return self.local_group.scale
 
     @scale.setter
     def scale(self, new_scale):
         current_anchored_position = self.anchored_position
-        self._scale = new_scale
         self.local_group.scale = new_scale
         self.anchored_position = current_anchored_position
 
@@ -438,13 +444,13 @@ class Label(displayio.Group):
         return (
             int(
                 self.x
-                + (self._boundingbox[0] * self._scale)
-                + round(self._anchor_point[0] * self._boundingbox[2] * self._scale)
+                + (self._boundingbox[0] * self.scale)
+                + round(self._anchor_point[0] * self._boundingbox[2] * self.scale)
             ),
             int(
                 self.y
-                + (self._boundingbox[1] * self._scale)
-                + round(self._anchor_point[1] * self._boundingbox[3] * self._scale)
+                + (self._boundingbox[1] * self.scale)
+                + round(self._anchor_point[1] * self._boundingbox[3] * self.scale)
             ),
         )
 
@@ -454,11 +460,11 @@ class Label(displayio.Group):
             return  # Note: anchor_point must be set before setting anchored_position
         self.x = int(
             new_position[0]
-            - (self._boundingbox[0] * self._scale)
-            - round(self._anchor_point[0] * (self._boundingbox[2] * self._scale))
+            - (self._boundingbox[0] * self.scale)
+            - round(self._anchor_point[0] * (self._boundingbox[2] * self.scale))
         )
         self.y = int(
             new_position[1]
-            - (self._boundingbox[1] * self._scale)
-            - round(self._anchor_point[1] * self._boundingbox[3] * self._scale)
+            - (self._boundingbox[1] * self.scale)
+            - round(self._anchor_point[1] * self._boundingbox[3] * self.scale)
         )
